==> ModuleXtender-1.5.1.zip: ModuleXtender/action.showImages.php <==
<?php
if (!isset($gCms)) exit;

/* -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

   Code for ModuleXtender admin action
   
   -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
   
  This code is aimed to upload and/or display images
   
*/
 
// Theme hack
$themeObject = new AdminTheme($gCms,  get_userid(), get_preference(get_userid(), 'admintheme', 'default'));


if (isset($params['module_name']) && isset($params['module_id']))
{
  $documents = MX_Image::doSelect(array('where' => array('modulename' => $params['module_name'], 'module_id' => $params['module_id'], 'type' => 'image')));
  
  $categories = MX_RelatedCategory::doSelect(array('where' => array(
	'modulename' => $params['module_name'], 
	'type' => 'images')));
  
  $this->smarty->assign('categories', $categories);
  
	 $rowclass = 'row1';
	  
	  foreach ($documents as $document)
	  {
	    $document->url = $document->getUrl($this->config['uploads_url'], 'images');
      $document->image = $document->url;
      $document->thumbnail = $document->getUrl($this->config['uploads_url'], 'images/admin_thumbnail');   
	    
	    $delete_url = html_entity_decode($this->CreateLink($id, 'manageImage', $returnid, 'delete documents', array(
	      'document_id' => $document->getId(),
	    'mx_action' => 'delete',
	      'js_call' => $params['js_call'],
	      ), '', true));
	      
	    $move_up_url = html_entity_decode($this->CreateLink($id, 'manageImage', $returnid, 'move documents', array(
	      'document_id' => $document->getId(),
	      'mx_action' => 'move_up',
	      'js_call' => $params['js_call'],
	      ), '', true));
	      
	    $move_down_url = html_entity_decode($this->CreateLink($id, 'manageImage', $returnid, 'move documents', array(
	      'document_id' => $document->getId(),
	      'mx_action' => 'move_down',
	      'js_call' => $params['js_call'],
	      ), '', true));
	    
	    $manage_url = html_entity_decode($this->CreateLink($id, 'manageImages', $returnid, 'manage documents', array(
	      'disable_theme' => 'true',
	      'document_id' => $document->getId(),
	     'js_call' => $params['js_call'],
	      ), '', true));
	    
	    
	    //   $this->ajax->GetRequestURL('ModuleXtender', 'UploadDocumentsBox', 'delete='.$document->getId()). // DELETE
	   $document->delete = '<a onClick="javascript: callHttpWithConfirmation(\'' . $delete_url . '\', \'Are you sure?\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/delete.gif', $this->Lang('delete'),'','','systemicon') 
        . '</a>';
	   
	   if ($document->getPosition() != 1)
	   {
	    $document->move_up = '<a onClick="javascript: callHttp(\'' . $move_up_url . '\'); ' . $params['js_call'] . '();">' .     
       $themeObject->DisplayImage('icons/system/sort_up.gif', $this->Lang('move_up'),'','','systemicon')
      // '<img src="/modules/ModuleXtender/images/icons/sort_up.gif" alt="Move up" border="0"/>'
        . '</a>';
	   }
	   else
	   {
	          $document->move_up = '';
	   }
	   
	   if ($document->getPosition() != (count($documents)))
	   {
	    $document->move_down = '<a onClick="javascript: callHttp(\'' . $move_down_url . '\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/sort_down.gif', $this->Lang('move_down'),'','','systemicon') 
      // <img src="/modules/ModuleXtender/images/icons/sort_down.gif" alt="Move down" border="0"/>
        . '</a>';
	   }
	   else 
	   {
	    $document->move_down = '';    
	   }
	      
	            $document->edit = '<a href="'.$manage_url.'" target="manageImage">' .
      $themeObject->DisplayImage('icons/system/edit.gif', $this->Lang('edit'),'','','systemicon') 
        . '</a>';
	    
	    
	    $document->rowclass = $rowclass;
	    ($rowclass=="row1"?$rowclass="row2":$rowclass="row1");
	  }
	  
	  if ($documents)
	  {
	    $this->smarty->assign('xtdocuments', $documents);
	    echo $this->ProcessTemplate('admin.showImages.tpl');
	  }
}

==> ModuleXtender-1.6.1.zip: ModuleXtender/action.showImages.php <==
<?php
if (!isset($gCms)) exit;

/* -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

   Code for ModuleXtender admin action
   
   -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
   
  This code is aimed to upload and/or display images
   
*/
 
// Theme hack
$themeObject = new AdminTheme($gCms,  get_userid(), get_preference(get_userid(), 'admintheme', 'default'));


if (isset($params['module_name']) && isset($params['module_id']))
{
  $documents = MX_Image::doSelect(array('where' => array('modulename' => $params['module_name'], 'module_id' => $params['module_id'], 'type' => 'image')));
  
  $categories = MX_RelatedCategory::doSelect(array('where' => array(
	'modulename' => $params['module_name'], 
	'type' => 'images')));
  
  $this->smarty->assign('categories', $categories);
  
	 $rowclass = 'row1';
	  $mx_documents = array();
	  foreach ($documents as $mx_document)
	  {
		$document = $mx_document;
	    $document->url = $document->getUrl($this->config['uploads_url'], 'images');
      $document->image = $document->url;
      $document->thumbnail = $document->getUrl($this->config['uploads_url'], 'images/admin_thumbnail');   
	    
	    $delete_url = html_entity_decode($this->CreateLink($id, 'manageImage', $returnid, 'delete documents', array(
	      'document_id' => $document->getId(),
	    'mx_action' => 'delete',
	      'js_call' => $params['js_call'],
	      ), '', true));
	      
	    $move_up_url = html_entity_decode($this->CreateLink($id, 'manageImage', $returnid, 'move documents', array(
	      'document_id' => $document->getId(),
	      'mx_action' => 'move_up',
	      'js_call' => $params['js_call'],
	      ), '', true));
	      
	    $move_down_url = html_entity_decode($this->CreateLink($id, 'manageImage', $returnid, 'move documents', array(
	      'document_id' => $document->getId(),
	      'mx_action' => 'move_down',
	      'js_call' => $params['js_call'],
	      ), '', true));
	    
	    $manage_url = html_entity_decode($this->CreateLink($id, 'manageImages', $returnid, 'manage documents', array(
	      'disable_theme' => 'true',
	      'document_id' => $document->getId(),
	     'js_call' => $params['js_call'],
	      ), '', true));
	    
	    
	    //   $this->ajax->GetRequestURL('ModuleXtender', 'UploadDocumentsBox', 'delete='.$document->getId()). // DELETE
	   $document->delete = '<a onClick="javascript: callHttpWithConfirmation(\'' . $delete_url . '\', \'Are you sure?\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/delete.gif', $this->Lang('delete'),'','','systemicon') 
        . '</a>';
	   
	   if ($document->getPosition() != 1)
	   {
	    $document->move_up = '<a onClick="javascript: callHttp(\'' . $move_up_url . '\'); ' . $params['js_call'] . '();">' .     
       $themeObject->DisplayImage('icons/system/sort_up.gif', $this->Lang('move_up'),'','','systemicon')
      // '<img src="/modules/ModuleXtender/images/icons/sort_up.gif" alt="Move up" border="0"/>'
        . '</a>';
	   }
	   else
	   {
	          $document->move_up = '';
	   }
	   
	   if ($document->getPosition() != (count($documents)))
	   {
	    $document->move_down = '<a onClick="javascript: callHttp(\'' . $move_down_url . '\'); ' . $params['js_call'] . '();">' .
      $themeObject->DisplayImage('icons/system/sort_down.gif', $this->Lang('move_down'),'','','systemicon') 
      // <img src="/modules/ModuleXtender/images/icons/sort_down.gif" alt="Move down" border="0"/>
        . '</a>';
	   }
	   else 
	   {
	    $document->move_down = '';    
	   }
	      
	            $document->edit = '<a href="'.$manage_url.'" target="manageImage">' .
      $themeObject->DisplayImage('icons/system/edit.gif', $this->Lang('edit'),'','','systemicon') 
        . '</a>';
	    
	    
	    $document->rowclass = $rowclass;
	    ($rowclass=="row1"?$rowclass="row2":$rowclass="row1");
		$mx_documents[] = $document;
	  }
	  
	  if ($documents)
	  {
	    $this->smarty->assign('xtdocuments', $mx_documents);
	    echo $this->ProcessTemplate('admin.showImages.tpl');
	  }
}
